@@ -179,6 +179,7 @@ Searching
 * Type / to start searching, then type what you want to find
 * Type ? to search backwards, then type what you want to find
 * Type RETURN to stop searching, or ESC to skip back to where the search started
+* Press up / down arrows while searching to access search history
 * Find next by typing 'n' (for "next")
 * Find previous by typing SHIFT-N or 'p' (for "previous")
 * Search is case sensitive if it contains any UPPER CASE CHARACTERS
@@ -444,6 +445,8 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 	consumeLessTermcapEnvs(screen.TerminalBackground(), chromaStyle, chromaFormatter)
 	styleUI(screen.TerminalBackground(), chromaStyle, chromaFormatter, p.StatusBarStyle, p.WithTerminalFg)
 
+	searchHistory = loadSearchHistory()
+
 	p.screen = screen
 	p.mode = PagerModeViewing{pager: p}
 	p.bookmarks = make(map[rune]scrollPosition)
